

set -ex



test -L $PREFIX/lib/libcufile.so
test -L $PREFIX/lib/libcufile_rdma.so
test -f $PREFIX/targets/sbsa-linux/include/cufile.h
test -L $PREFIX/targets/sbsa-linux/lib/libcufile.so
test -L $PREFIX/targets/sbsa-linux/lib/libcufile_rdma.so
test -d $PREFIX/man/man3
exit 0
